[PATCH] D37374: [PATCH][ARM] Enable the use of SVC anywhere in an IT block

Andre Vieira via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Mon Sep 11 04:12:40 PDT 2017


This revision was automatically updated to reflect the committed changes.
Closed by commit rL312908: [ARM] Enable the use of SVC anywhere in an IT block (authored by avieira).

Changed prior to commit:
  https://reviews.llvm.org/D37374?vs=113531&id=114563#toc

Repository:
  rL LLVM

https://reviews.llvm.org/D37374

Files:
  llvm/trunk/lib/Target/ARM/AsmParser/ARMAsmParser.cpp
  llvm/trunk/test/MC/ARM/basic-thumb2-instructions.s


Index: llvm/trunk/test/MC/ARM/basic-thumb2-instructions.s
===================================================================
--- llvm/trunk/test/MC/ARM/basic-thumb2-instructions.s
+++ llvm/trunk/test/MC/ARM/basic-thumb2-instructions.s
@@ -3113,12 +3113,18 @@
         svceq #255
         it ne
         swine #33
+        itt eq
+        svceq #0
+        svceq #1
 
 @ CHECK: svc	#0                      @ encoding: [0x00,0xdf]
 @ CHECK: it	eq                      @ encoding: [0x08,0xbf]
 @ CHECK: svceq	#255                    @ encoding: [0xff,0xdf]
 @ CHECK: it	ne                      @ encoding: [0x18,0xbf]
 @ CHECK: svcne	#33                     @ encoding: [0x21,0xdf]
+@ CHECK: itt    eq                      @ encoding: [0x04,0xbf]
+@ CHECK: svceq  #0                      @ encoding: [0x00,0xdf]
+@ CHECK: svceq  #1                      @ encoding: [0x01,0xdf]
 
 
 @------------------------------------------------------------------------------
Index: llvm/trunk/lib/Target/ARM/AsmParser/ARMAsmParser.cpp
===================================================================
--- llvm/trunk/lib/Target/ARM/AsmParser/ARMAsmParser.cpp
+++ llvm/trunk/lib/Target/ARM/AsmParser/ARMAsmParser.cpp
@@ -8717,9 +8717,10 @@
 bool ARMAsmParser::isITBlockTerminator(MCInst &Inst) const {
   const MCInstrDesc &MCID = MII.get(Inst.getOpcode());
 
-  // All branch & call instructions terminate IT blocks.
-  if (MCID.isTerminator() || MCID.isCall() || MCID.isReturn() ||
-      MCID.isBranch() || MCID.isIndirectBranch())
+  // All branch & call instructions terminate IT blocks with the exception of
+  // SVC.
+  if (MCID.isTerminator() || (MCID.isCall() && Inst.getOpcode() != ARM::tSVC) ||
+      MCID.isReturn() || MCID.isBranch() || MCID.isIndirectBranch())
     return true;
 
   // Any arithmetic instruction which writes to the PC also terminates the IT


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D37374.114563.patch
Type: text/x-patch
Size: 1861 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20170911/95a44e78/attachment.bin>


More information about the llvm-commits mailing list